#!/bin/sh -euf
#
# Copyright (C) 2023 UBports Foundation
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License version 3 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Authored by: Ratchanan Srirattanamet <ratchanan@ubports.com>

# Note: can afford to do destructive migration since this is just a cache.

# Contains .desktop files, many of which are obsolete due to application
# renamings. Files in the new location will be generated by click hook.
old_path="${HOME}/.cache/ubuntu-app-launch"

if [ -d "$old_path" ]; then
    rm -r "$old_path"
fi
